@@ -436,7 +436,7 @@ setup_monitor(t_global_monitor *global)
 {
     gint count;
 #if GTK_CHECK_VERSION (3, 16, 0)
-    gchar * css;
+    gchar *css, *color;
 #endif
 
     gtk_widget_hide(GTK_WIDGET(global->uptime->ebox));
@@ -449,15 +449,16 @@ setup_monitor(t_global_monitor *global)
                            global->monitor[count]->options.label_text);
 
 #if GTK_CHECK_VERSION (3, 16, 0)
+        color = gdk_rgba_to_string(&global->monitor[count]->options.color);
 #if GTK_CHECK_VERSION (3, 20, 0)
-        css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
+        css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }", color);
 #else
-        css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
+        css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }", color);
 #endif
-                              gdk_rgba_to_string(&global->monitor[count]->options.color));
         gtk_css_provider_load_from_data (
             g_object_get_data(G_OBJECT(global->monitor[count]->status), "css_provider"),
             css, strlen(css), NULL);
+        g_free(color);
         g_free(css);
 #else
         gtk_widget_override_background_color(GTK_WIDGET(global->monitor[count]->status),
@@ -575,7 +576,7 @@ monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *global)
 {
     gint count;
     XfceRc *rc;
-    char *file;
+    char *file, *color;
 
     if (!(file = xfce_panel_plugin_save_location (plugin, TRUE)))
         return;
@@ -601,7 +602,9 @@ monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *global)
         xfce_rc_write_bool_entry (rc, "Use_Label",
                 global->monitor[count]->options.use_label);
 
-        xfce_rc_write_entry (rc, "Color", gdk_rgba_to_string(&global->monitor[count]->options.color));
+        color = gdk_rgba_to_string (&global->monitor[count]->options.color);
+        xfce_rc_write_entry (rc, "Color", color);
+        g_free (color);
 
         xfce_rc_write_entry (rc, "Text",
             global->monitor[count]->options.label_text ?
@@ -806,7 +809,6 @@ static void new_monitor_setting(t_global_monitor *global, GtkGrid *grid, int pos
     gtk_widget_set_halign (label, GTK_ALIGN_START);
     gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
     gtk_widget_set_margin_start (label, 12);
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
     gtk_grid_attach (GTK_GRID(subgrid), label, 0, 0, 1, 1);
 
     /* Entry for the optional monitor label */
@@ -822,6 +824,7 @@ static void new_monitor_setting(t_global_monitor *global, GtkGrid *grid, int pos
 
     /* Colorbutton to set the progressbar color */
     button = gtk_color_button_new_with_rgba(colorvar);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
     gtk_widget_set_halign(button, GTK_ALIGN_START);
     g_object_set_data(G_OBJECT(button), "colorvar", colorvar);
     g_signal_connect(G_OBJECT(button), "color-set",
